import { $, implicit$FirstArg } from '@builder.io/qwik';
/**
 * See {@link valiForm$}
 */
export function valiFormQrl(schema) {
    return $(async (values) => {
        const resolvedSchema = await schema.resolve();
        const result = await (typeof resolvedSchema === 'function'
            ? resolvedSchema()
            : resolvedSchema)._parse(values, { abortPipeEarly: true });
        return result.issues
            ? result.issues.reduce((errors, issue) => ({
                ...errors,
                [issue.path.map(({ key }) => key).join('.')]: issue.message,
            }), {})
            : {};
    });
}
/**
 * Creates a validation functions that parses the Valibot schema of a form.
 *
 * @param schema A Valibot schema.
 *
 * @returns A validation function.
 */
export const valiForm$ = implicit$FirstArg(valiFormQrl);
