import { $, implicit$FirstArg } from '@builder.io/qwik';
import { getParsedZodSchema } from '../utils';
/**
 * See {@link zodForm$}
 */
export function zodFormQrl(schema) {
    return $(async (values) => {
        const result = await getParsedZodSchema(schema, values);
        return result.success
            ? {}
            : result.error.issues.reduce((errors, error) => {
                const path = error.path.join('.');
                if (!errors[path]) {
                    errors[path] = error.message;
                }
                return errors;
            }, {});
    });
}
/**
 * Creates a validation functions that parses the Zod schema of a form.
 *
 * @param schema A Zod schema.
 *
 * @returns A validation function.
 */
export const zodForm$ = implicit$FirstArg(zodFormQrl);
