import { Field, Form, FieldArray } from '../components';
import { useFormStore } from './useFormStore';
/**
 * Creates and returns the store of the form as well as a linked Form, Field
 * and FieldArray component.
 *
 * @param options The form options.
 *
 * @returns The store and linked components.
 */
export function useForm(options) {
    // Use form store
    const form = useFormStore(options);
    // Return form store and linked components
    return [
        form,
        {
            Form: (props) => Form({ of: form, action: options.action, ...props }),
            Field: (props) => Field({ of: form, ...props }),
            FieldArray: (props) => FieldArray({ of: form, ...props }),
        },
    ];
}
