import { getFieldStore, getFieldArrayStore } from '../utils';
/**
 * Returns the error of the specified field or field array.
 *
 * @param form The form of the field or field array.
 * @param name The name of the field or field array.
 *
 * @returns The error of the field or field array.
 */
export function getError(form, name, { shouldActive = true, shouldTouched = false, shouldDirty = false, } = {}) {
    // Return error if field or field array corresponds to filter options
    for (const fieldOrFieldArray of [
        getFieldStore(form, name),
        getFieldArrayStore(form, name),
    ]) {
        if (fieldOrFieldArray &&
            (!shouldActive || fieldOrFieldArray.active) &&
            (!shouldTouched || fieldOrFieldArray.touched) &&
            (!shouldDirty || fieldOrFieldArray.dirty)) {
            return fieldOrFieldArray.error;
        }
    }
    // Otherwise return undefined
    return undefined;
}
