import { getFieldStore } from '../utils';
/**
 * Returns the value of the specified field.
 *
 * @param form The form of the field.
 * @param name The name of the field.
 * @param options The value options.
 *
 * @returns The value of the field.
 */
export function getValue(form, name, { shouldActive = true, shouldTouched = false, shouldDirty = false, shouldValid = false, } = {}) {
    // Get store of specified field
    const field = getFieldStore(form, name);
    // Continue if field corresponds to filter options
    if (field &&
        (!shouldActive || field.active) &&
        (!shouldTouched || field.touched) &&
        (!shouldDirty || field.dirty) &&
        (!shouldValid || !field.error)) {
        // Return value of field
        return field.value;
    }
    // Otherwise return undefined
    return undefined;
}
